@@ -1,11 +1,8 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-
+from urllib.parse import urljoin
 from xml.etree.ElementTree import ParseError
 
-from six.moves.urllib.parse import urljoin
-from datetime import datetime, date
-import time
+from datetime import date
 import logging
 import json
 import xml.etree.ElementTree as ET
